import os

import pandas as pd
import sqlalchemy
from ibm_watsonx_ai import APIClient
from pandas import DataFrame
from sqlalchemy import create_engine

from genai_4_dps_helper.base_obj import BaseObj


class PrestoConnection(BaseObj):
    def __init__(
        self,
        client: APIClient,
        server_pem_path="/tmp/presto.crt",
        write_cert_file: bool = False,
    ):
        """Connects to watsonx.data Presto SQL speified in the connections property of 'client'.
        It expects the connection to be SSL and the cerficate is available in the connection metadata.

        Args:
            client (APIClient): A connected APIClient to watsonx.ai.
            server_pem_path (str, optional): Path to store the PEM file in. Defaults to "/tmp/presto.crt".
            write_cert_file (bool, optional): If true get the certifiate from the connection and write it to server_pem_path
        """
        super(PrestoConnection, self).__init__()

        client_connections: DataFrame = client.connections.list()
        presto_connection_id = client_connections.loc[
            client_connections["NAME"] == "Presto", "ID"
        ].values[0]
        presto_credentials = (
            client.connections.get_details(presto_connection_id)
            .get("entity")
            .get("properties")
        )
        # if os.path.isfile(server_pem_path):
        #     os.remove(server_pem_path)
        # with open(server_pem_path, "a") as fp:
        #     fp.write(presto_credentials["ssl_certificate"])

        hostname = presto_credentials["host"]
        port = presto_credentials["port"]
        userid = presto_credentials["username"]
        password = presto_credentials["password"]
        catalog = "tpch"
        schema = "tiny"
        connect_args = {
            "protocol": "https",
            "requests_kwargs": {"verify": f"{server_pem_path}"},
        }

        con_str: str = (
            f"presto://{userid}:{password}@{hostname}:{port}/{catalog}/{schema}"
        )
        print(con_str)

        self._engine = create_engine(
            f"presto://{userid}:{password}@{hostname}:{port}/{catalog}/{schema}",
            connect_args=connect_args,
        )

    def select_sql(self, sql: str) -> DataFrame:
        return pd.read_sql_query(sql, self._engine)
